Author: Andreas Tille <tille@debian.org>
Last-Update: Tue, 29 Nov 2022 16:09:55 +0100
Description: Fix sequence of imports

--- a/setup.py
+++ b/setup.py
@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 import sys
+from setuptools import Extension, setup, find_packages
 from distutils.command.build_ext import build_ext
 from distutils.sysconfig import get_python_inc
-from setuptools import Extension, setup, find_packages
 from pathlib import Path
 from Cython.Build import cythonize
 from Cython.Compiler import Options
